==> fluss-0.8.0-incubating-src.tgz: fluss-0.8.0-incubating/fluss-lake/fluss-lake-iceberg/src/main/java/org/apache/fluss/lake/iceberg/maintenance/RewriteDataFileResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.fluss.lake.iceberg.maintenance;

import org.apache.iceberg.DataFile;

import java.io.Serializable;
import java.util.List;

/** The result for rewrite iceberg data files. */
public class RewriteDataFileResult implements Serializable {

    private static final long serialVersionUID = 1L;

    private final long snapshotId;
    private final List<DataFile> deletedDataFiles;
    private final List<DataFile> addedDataFiles;

    public RewriteDataFileResult(
            long snapshotId, List<DataFile> deletedDataFiles, List<DataFile> addedDataFiles) {
        this.snapshotId = snapshotId;
        this.deletedDataFiles = deletedDataFiles;
        this.addedDataFiles = addedDataFiles;
    }

    public List<DataFile> deletedDataFiles() {
        return deletedDataFiles;
    }

    public List<DataFile> addedDataFiles() {
        return addedDataFiles;
    }

    public long snapshotId() {
        return snapshotId;
    }

    @Override
    public String toString() {
        return "RewriteDataFileResult{"
                + "snapshotId="
                + snapshotId
                + ", deletedDataFiles="
                + deletedDataFiles
                + ", addedDataFiles="
                + addedDataFiles
                + '}';
    }
}

==> fluss-0.9.0-incubating-src.tgz: fluss-0.9.0-incubating/fluss-lake/fluss-lake-iceberg/src/main/java/org/apache/fluss/lake/iceberg/maintenance/RewriteDataFileResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.fluss.lake.iceberg.maintenance;

import org.apache.iceberg.util.DataFileSet;

import java.io.Serializable;

/** The result for rewrite iceberg data files. */
public class RewriteDataFileResult implements Serializable {

    private static final long serialVersionUID = 1L;

    private final long snapshotId;
    private final DataFileSet deletedDataFiles;
    private final DataFileSet addedDataFiles;

    public RewriteDataFileResult(
            long snapshotId, DataFileSet deletedDataFiles, DataFileSet addedDataFiles) {
        this.snapshotId = snapshotId;
        this.deletedDataFiles = deletedDataFiles;
        this.addedDataFiles = addedDataFiles;
    }

    public DataFileSet deletedDataFiles() {
        return deletedDataFiles;
    }

    public DataFileSet addedDataFiles() {
        return addedDataFiles;
    }

    public long snapshotId() {
        return snapshotId;
    }

    @Override
    public String toString() {
        return "RewriteDataFileResult{"
                + "snapshotId="
                + snapshotId
                + ", deletedDataFiles="
                + deletedDataFiles
                + ", addedDataFiles="
                + addedDataFiles
                + '}';
    }
}
